@@ -1,10 +1,10 @@
-from .generate_annofile import *
+from .generate import *
 from .modify import *
 from .parse import *
 from .check import *
 from .visualization import *
 
-__all__ = ['generate_annofile',
+__all__ = ['generate_annofile', 'generate_annotxt',
            'parse_label', 'parse_txt',
            'modify_annoroot', 'modify_annocls', 'modify_label',
            'print_label', 'check_bboxlabel',
