@@ -28,9 +28,9 @@ def check_bboxlabel(root, label_suffix, area_limit, cls_limit):
     anno_paths = glob(os.path.join(root, f'*{label_suffix}'))
 
     label_cls = print_label(root, label_suffix)
-    if set(label_cls) != cls_limit:
+    if set(label_cls) != set(cls_limit):
         raise ValueError('label not match')
-    for anno_path in anno_paths:
+    for anno_path in track_iter_progress(anno_paths):
         objs = parse_label(anno_path, label_suffix, cls_limit)
         bboxes = objs[:, 0:4]
         whs = bboxes[:, 2:] - bboxes[:, 0:2]
