@@ -8,11 +8,14 @@ def parse_label(path, label_suffix, classes=None):
         datas = ET.parse(str(path))
         objs = []
         for obj in datas.findall('object'):
-            try:
-                cls = classes.index(obj.find('name').text.lower()) if classes is not None else 0
-            except:
-                cls = 0
-                print(f'{Path(path).name} not in {classes}')
+            if classes is None:
+                cls =0
+            else:
+                try:
+                    cls = classes.index(obj.find('name').text.lower()) if classes is not None else 0
+                except:
+                    cls = 0
+                    print(f'{Path(path).name} not in {classes}')
             bndbox = obj.find('bndbox')
             bbox = [int(x.text) for x in bndbox] + [cls]
             objs.append(bbox)
