@@ -2,5 +2,6 @@ from .progressbar import track_iter_progress
 from .path import *
 from .img import *
 
-__all__ = ['track_iter_progress', 'mkdir_or_exist',
+__all__ = ['track_iter_progress',
+           'mkdir_or_exist', 'clear_directory',
            'imwrite', 'imread', 'imshow', 'imshow_with_bbox']
